@@ -16,10 +16,11 @@ from spectrafit.models import SolverModels
 from spectrafit.plotting import PlotSpectra
 from spectrafit.report import PrintingResults
 from spectrafit.report import PrintingStatus
+
+# from spectrafit.tools import check_keywords_consistency
 from spectrafit.tools import PostProcessing
 from spectrafit.tools import PreProcessing
 from spectrafit.tools import SaveResult
-from spectrafit.tools import check_keywords_consistency
 from spectrafit.tools import load_data
 from spectrafit.tools import read_input_file
 
@@ -67,28 +68,28 @@ def get_args() -> Dict[str, Any]:
         "--energy_start",
         type=float,
         default=None,
-        help="Starting energy in eV; default to start of energy.",
+        help="Starting energy in eV; default to start of energy; default to None.",
     )
     parser.add_argument(
         "-e1",
         "--energy_stop",
         type=float,
         default=None,
-        help="Ending energy in eV; default to end of energy.",
+        help="Ending energy in eV; default to end of energy; default to None.",
     )
     parser.add_argument(
         "-s",
         "--smooth",
         type=int,
         default=None,
-        help="Number of smooth points for lmfit; default to 0.",
+        help="Number of smooth points for lmfit; default to None.",
     )
     parser.add_argument(
         "-sh",
         "--shift",
         type=float,
         default=None,
-        help="Constant applied energy shift",
+        help="Constant applied energy shift; default to 0.",
     )
     parser.add_argument(
         "-c",
@@ -125,6 +126,14 @@ def get_args() -> Dict[str, Any]:
         default=None,
         help="Selected the header for the dataframe; default to None.",
     )
+    parser.add_argument(
+        "-cm",
+        "--comment",
+        type=str,
+        default=None,
+        help="Lines with comment characters like '#' should not be parsed;"
+        " default to None.",
+    )
     parser.add_argument(
         "-g",
         "--global",
@@ -149,7 +158,6 @@ def get_args() -> Dict[str, Any]:
         action="store_true",
         default=False,
     )
-
     parser.add_argument(
         "-np",
         "--noplot",
@@ -227,7 +235,7 @@ def extracted_from_command_line_runner() -> Dict[str, Any]:
     """
     result = get_args()
     _args = read_input_file(result["input"])
-    check_keywords_consistency(check_args=_args["settings"], ref_args=result)
+    # check_keywords_consistency(check_args=_args["settings"], ref_args=result)
     if "settings" in _args.keys():
         for key in _args["settings"].keys():
             result[key] = _args["settings"][key]
@@ -288,7 +296,3 @@ def fitting_routine(args: Dict[str, Any]) -> Tuple[pd.DataFrame, dict]:
     PrintingResults(args=args, minimizer=minimizer, result=result)()
 
     return df, args
-
-
-if __name__ == "__main__":
-    command_line_runner()
